Gate-based network to node-based network
----------------------------------------

**Header:** ``mockturtle/algorithms/gates_to_nodes.hpp``

Algorithm
~~~~~~~~~

.. doxygenfunction:: mockturtle::gates_to_nodes
.. doxygenfunction:: mockturtle::single_node_network
